"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

from builtins import (
    bool,
    float,
    int,
)
from collections.abc import (
    Iterable,
)
from fr24.proto._common_pb2 import (
    Flight,
)
from google.protobuf.descriptor import (
    Descriptor,
    FileDescriptor,
)
from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer,
)
from google.protobuf.message import (
    Message,
)
from typing import (
    Literal,
    final,
)

DESCRIPTOR: FileDescriptor

@final
class Geolocation(Message):
    DESCRIPTOR: Descriptor

    LAT_FIELD_NUMBER: int
    LON_FIELD_NUMBER: int
    lat: float
    """Latitude, degrees, -90 to 90"""
    lon: float
    """Longitude, degrees, -180 to 180"""
    def __init__(
        self,
        *,
        lat: float = ...,
        lon: float = ...,
    ) -> None: ...
    def ClearField(self, field_name: Literal["lat", b"lat", "lon", b"lon"]) -> None: ...

@final
class NearestFlightsRequest(Message):
    DESCRIPTOR: Descriptor

    LOCATION_FIELD_NUMBER: int
    RADIUS_FIELD_NUMBER: int
    LIMIT_FIELD_NUMBER: int
    radius: int
    """Radius, metres"""
    limit: int
    """Maximum number of aircraft to return"""
    @property
    def location(self) -> Geolocation: ...
    def __init__(
        self,
        *,
        location: Geolocation | None = ...,
        radius: int = ...,
        limit: int = ...,
    ) -> None: ...
    def HasField(self, field_name: Literal["location", b"location"]) -> bool: ...
    def ClearField(self, field_name: Literal["limit", b"limit", "location", b"location", "radius", b"radius"]) -> None: ...

@final
class NearbyFlight(Message):
    DESCRIPTOR: Descriptor

    FLIGHT_FIELD_NUMBER: int
    DISTANCE_FIELD_NUMBER: int
    distance: int
    """Distance from the location, metres"""
    @property
    def flight(self) -> Flight: ...
    def __init__(
        self,
        *,
        flight: Flight | None = ...,
        distance: int = ...,
    ) -> None: ...
    def HasField(self, field_name: Literal["flight", b"flight"]) -> bool: ...
    def ClearField(self, field_name: Literal["distance", b"distance", "flight", b"flight"]) -> None: ...

@final
class NearestFlightsResponse(Message):
    DESCRIPTOR: Descriptor

    FLIGHTS_LIST_FIELD_NUMBER: int
    @property
    def flights_list(self) -> RepeatedCompositeFieldContainer[NearbyFlight]: ...
    def __init__(
        self,
        *,
        flights_list: Iterable[NearbyFlight] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: Literal["flights_list", b"flights_list"]) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

from fr24.proto._common_pb2 import (
    A225 as A225,
    A320 as A320,
    A330 as A330,
    A343 as A343,
    A346 as A346,
    A380 as A380,
    A3ST as A3ST,
    ADSB as ADSB,
    AIRBORNE as AIRBORNE,
    AIRBORNE_ONLY as AIRBORNE_ONLY,
    ALL as ALL,
    ASCENDING as ASCENDING,
    ASW20 as ASW20,
    AUS as AUS,
    AircraftInfo as AircraftInfo,
    AltArrival as AltArrival,
    B736 as B736,
    B738 as B738,
    B747 as B747,
    B757 as B757,
    B767 as B767,
    B777 as B777,
    BACKGROUND as BACKGROUND,
    BALL as BALL,
    BUSINESS_JETS as BUSINESS_JETS,
    C206 as C206,
    C303 as C303,
    CARGO as CARGO,
    CONC as CONC,
    Coordinate as Coordinate,
    DESCENDING as DESCENDING,
    DIVERSION as DIVERSION,
    DOWNED_AIRCRAFT as DOWNED_AIRCRAFT,
    DRON as DRON,
    DRONES as DRONES,
    DataSource as DataSource,
    DelayStatus as DelayStatus,
    Duration as Duration,
    EC as EC,
    EMERGENCY as EMERGENCY,
    EMSAvailability as EMSAvailability,
    EMSInfo as EMSInfo,
    ESTIMATED as ESTIMATED,
    EmergencyStatus as EmergencyStatus,
    ExtendedFlightInfo as ExtendedFlightInfo,
    ExtraFlightInfo as ExtraFlightInfo,
    FAA as FAA,
    FGTR as FGTR,
    FLARM as FLARM,
    FOKKER100 as FOKKER100,
    FULLY_VISIBLE as FULLY_VISIBLE,
    Fix as Fix,
    Flight as Flight,
    FlightPlan as FlightPlan,
    FlightProgress as FlightProgress,
    FlightStage as FlightStage,
    GENERAL_AVIATION as GENERAL_AVIATION,
    GENERAL_EMERGENCY as GENERAL_EMERGENCY,
    GLIDERS as GLIDERS,
    GRAY as GRAY,
    GREEN as GREEN,
    GRND as GRND,
    GROUND_ONLY as GROUND_ONLY,
    GROUND_VEHICLES as GROUND_VEHICLES,
    HELICOPTERS as HELICOPTERS,
    ISS as ISS,
    Icon as Icon,
    ImageInfo as ImageInfo,
    LIFEGUARD_MEDICAL_EMERGENCY as LIFEGUARD_MEDICAL_EMERGENCY,
    LIGHTER_THAN_AIR as LIGHTER_THAN_AIR,
    LIVE as LIVE,
    LJ60 as LJ60,
    MD11 as MD11,
    MILITARY_AND_GOVERNMENT as MILITARY_AND_GOVERNMENT,
    MINIMUM_FUEL as MINIMUM_FUEL,
    MLAT as MLAT,
    NONE as NONE,
    NON_CATEGORIZED as NON_CATEGORIZED,
    NORMAL as NORMAL,
    NOT_AVAILABLE as NOT_AVAILABLE,
    NOT_VISIBLE as NOT_VISIBLE,
    NO_COMMUNICATIONS as NO_COMMUNICATIONS,
    NO_EMERGENCY as NO_EMERGENCY,
    ON_GROUND as ON_GROUND,
    OTHER_DATA_SOURCE as OTHER_DATA_SOURCE,
    OTHER_SERVICE as OTHER_SERVICE,
    PARTIALLY_VISIBLE as PARTIALLY_VISIBLE,
    PASSENGER as PASSENGER,
    Point as Point,
    PositionBuffer as PositionBuffer,
    Q300 as Q300,
    RED as RED,
    RESERVED as RESERVED,
    RJ85 as RJ85,
    RadarHistoryRecord as RadarHistoryRecord,
    RecentPosition as RecentPosition,
    RestrictionVisibility as RestrictionVisibility,
    Route as Route,
    SAT as SAT,
    SATELLITE as SATELLITE,
    SI2 as SI2,
    SLEI as SLEI,
    SPIDERTRACKS as SPIDERTRACKS,
    Schedule as Schedule,
    ScheduleInfo as ScheduleInfo,
    Service as Service,
    SourceStats as SourceStats,
    Stats as Stats,
    Status as Status,
    Tick as Tick,
    TrafficType as TrafficType,
    TrailPoint as TrailPoint,
    UAT as UAT,
    UNKNOWN as UNKNOWN,
    UNLAWFUL_INTERFERENCE as UNLAWFUL_INTERFERENCE,
    YELLOW as YELLOW,
)
from fr24.proto._fetch_search_index_pb2 import (
    FetchSearchIndexRequest as FetchSearchIndexRequest,
    FetchSearchIndexResponse as FetchSearchIndexResponse,
    FlightSearchData as FlightSearchData,
)
from fr24.proto._flight_details_pb2 import (
    FlightDetailsRequest as FlightDetailsRequest,
    FlightDetailsResponse as FlightDetailsResponse,
    FlightProgress as FlightProgress,
)
from fr24.proto._follow_flight_pb2 import (
    FollowFlightRequest as FollowFlightRequest,
    FollowFlightResponse as FollowFlightResponse,
)
from fr24.proto._health_pb2 import (
    Ping as Ping,
    Pong as Pong,
)
from fr24.proto._historic_trail_pb2 import (
    HistoricTrailRequest as HistoricTrailRequest,
    HistoricTrailResponse as HistoricTrailResponse,
)
from fr24.proto._live_feed_pb2 import (
    AirlineFilter as AirlineFilter,
    AirlineFilterType as AirlineFilterType,
    AirportFilter as AirportFilter,
    AirportFilterType as AirportFilterType,
    BOTH as BOTH,
    Filter as Filter,
    INBOUND as INBOUND,
    Interval as Interval,
    LiveFeedRequest as LiveFeedRequest,
    LiveFeedResponse as LiveFeedResponse,
    LocationBoundaries as LocationBoundaries,
    OPERATED_BY as OPERATED_BY,
    OUTBOUND as OUTBOUND,
    PAINTED_AS as PAINTED_AS,
    PlaybackRequest as PlaybackRequest,
    PlaybackResponse as PlaybackResponse,
    VisibilitySettings as VisibilitySettings,
)
from fr24.proto._live_flight_status_pb2 import (
    LiveFlightStatus as LiveFlightStatus,
    LiveFlightStatusData as LiveFlightStatusData,
    LiveFlightsStatusRequest as LiveFlightsStatusRequest,
    LiveFlightsStatusResponse as LiveFlightsStatusResponse,
)
from fr24.proto._live_trail_pb2 import (
    LiveTrailRequest as LiveTrailRequest,
    LiveTrailResponse as LiveTrailResponse,
)
from fr24.proto._nearest_flights_pb2 import (
    Geolocation as Geolocation,
    NearbyFlight as NearbyFlight,
    NearestFlightsRequest as NearestFlightsRequest,
    NearestFlightsResponse as NearestFlightsResponse,
)
from fr24.proto._playback_flight_pb2 import (
    PlaybackFlightRequest as PlaybackFlightRequest,
    PlaybackFlightResponse as PlaybackFlightResponse,
)
from fr24.proto._top_flights_pb2 import (
    FollowedFlight as FollowedFlight,
    TopFlightsRequest as TopFlightsRequest,
    TopFlightsResponse as TopFlightsResponse,
)
from google.protobuf.descriptor import (
    FileDescriptor,
)

DESCRIPTOR: FileDescriptor
